@@ -17,6 +17,9 @@ class IFDefinition:
     DISTRIBUTING_MODE_DIRECT = b'Direct'
     DISTRIBUTING_MODE_SERVICE = b'Service'
     HEARTBEAT_LIVETIME = 10
+    DEFAULT_PORT_TCP = 81
+    DEFAULT_PORT_WEBSOCKET_SSL = 82
+    DEFAULT_PORT_WEBSOCKET = 83
 
 
 class IFException(Exception):
@@ -345,3 +348,17 @@ class Invocation:
         #         self.communicator.sendLater(error)
         #     return
 
+class IFAddress:
+    @classmethod
+    def parseAddress(clz, address):
+        sp1 = address.split('://')
+        if len(sp1) > 2:
+            raise ValueError(f'Invalid address: {address}')
+        else:
+            protocol = sp1[0] if len(sp1) == 2 else 'tcp'
+            if protocol != 'tcp':
+                raise ValueError(f'Invalid protocol "{protocol}" of address "{address}"')
+            sp2 = sp1[-1].split(':')
+            ip = sp2[0]
+            port = IFDefinition().DEFAULT_PORT_TCP if len(sp2) == 1 else sp2[1]
+            return [protocol, ip, port]
