@@ -4,7 +4,7 @@ __email__ = 'hwaipy@gmail.com'
 
 import zmq
 from zmq.eventloop.zmqstream import ZMQStream
-from interactionfreepy.core import IFException, Message, Invocation, IFLoop, IFDefinition
+from interactionfreepy.core import IFException, Message, Invocation, IFLoop, IFDefinition, IFAddress
 import time
 import threading
 import asyncio
@@ -12,12 +12,12 @@ import logging
 
 class IFWorker(object):
     def __init__(self, endpoint, serviceName=None, serviceObject=None, interfaces=[], blocking=True, timeout=None, force=False):
-        self.__endpoint = endpoint
+        self.address = IFAddress.parseAddress(endpoint)
         self.socket = zmq.Context().socket(zmq.DEALER)
         self.__stream = ZMQStream(self.socket, IFLoop.INSTANCE)
         self.__stream.on_recv(self.__onMessage)
         self.__stream.socket.setsockopt(zmq.LINGER, 0)
-        self.__stream.connect(self.__endpoint)
+        self.__stream.connect(f'{self.address[0]}://{self.address[1]}:{self.address[2]}')
         self.__waitingMap = {}
         self.__waitingMapLock = threading.Lock()
         self.blocking = blocking
@@ -314,7 +314,7 @@ if __name__ == '__main__':
     #         print(arg)
     #         return 1.1
 
-    # worker = IFWorker('tcp://172.16.60.200:224', 'TS', Target())
+    # worker = IFWorker('tcp://172.16.60.200:81', 'TS', Target())
     # print(worker.listServiceMeta())
     # # print(worker.HMC7044EvalAlice.checkChannel(1))
     # IFLoop.join()
